@@ -21,6 +21,8 @@ getOptionList <- function()
             help="disable biocViews-specific checks (for non-BioC packages)"),
         make_option("--no-check-bbs", action="store_true",
             help="disable BBS-specific checks (for non-BioC packages). Valid DESCRIPTION"),
+        make_option("--no-check-description", action="store_true",
+            help="disable DESCRIPTION file checks"),
         make_option("--no-check-namespace", action="store_true",
             help="disable namespace checks"),
         make_option("--no-check-vignettes", action="store_true",
@@ -72,20 +74,6 @@ usage <- function()
     }
 }
 
-.BiocCheckFromCommandLine <- function()
-{
-    .Deprecated(msg="\nDEPRECATED: R CMD BiocCheck\n  Running BiocCheck from command line is deprecated in 3.12 and will be removed in 3.13.\n  Please run from within R as\n `BiocCheck(<pkg>)` or `BiocCheck(<pkg.tar.gz>)`")
-    parser <- getArgParser()
-    tryCatch({
-        arguments <- parse_args(parser, positional_arguments = 1)
-    }, error = function(err) { stop("Bad Command Line Option\n","See 'R CMD BiocCheck --help'")})
-    opt <- arguments$options
-    file <- arguments$args
-
-    opt$Called_from_command_line <- TRUE
-    BiocCheck(file, opt)
-}
-
 BiocCheck <- function(package=".", ...)
 {
     .zeroCounters()
@@ -131,6 +119,9 @@ BiocCheck <- function(package=".", ...)
         checkRemotesUsage(package_dir)
     }
 
+    handleCheck("Checking for 'LazyData: true' usage...")
+    checkLazyDataUsage(package_dir)
+
     if (is.null(dots[["no-check-version-num"]])){
         handleCheck("Checking version number...")
         if (!checkingDir) {
@@ -184,6 +175,12 @@ BiocCheck <- function(package=".", ...)
         checkBBScompatibility(package_dir, source_tarball)
     }
 
+    if (is.null(dots[["no-check-description"]])) {
+        ## the following is redundant with other outputs...
+        ## handleCheck("Checking DESCRIPTION file...")
+        checkDESCRIPTIONFile(package_dir)
+    }
+
     if (is.null(dots[["no-check-namespace"]])){
         handleCheck("Checking DESCRIPTION/NAMESPACE consistency...")
         checkDescriptionNamespaceConsistency(package_name)
@@ -196,32 +193,23 @@ BiocCheck <- function(package=".", ...)
             }
     }
 
-    if (is.null(dots[["no-check-vignettes"]]))
-    {
-        pkgType <- getPkgType(package_dir)
-        if ((is.na(pkgType)) || pkgType == "Software")
-        {
-            handleCheck("Checking vignette directory...")
-            msg <- sprintf(
-                "This is a%s package",
-                if (is.na(pkgType)) "n unknown type of" else " software")
-            handleMessage(msg)
-            checkVignetteDir(package_dir, checkingDir)
-            if ("build-output-file" %in% names(dots))
-            {
-                handleCheck(
-                    "Checking whether vignette is built with 'R CMD build'...")
-                checkIsVignetteBuilt(package_dir, dots[["build-output-file"]])
-            }
-        } else {
-            handleMessage(
-                "This is not a software package, skipping vignette checks...")
+    handleCheck("Checking .Rbuildignore...")
+    checkRbuildignore(package_dir)
+
+    if (is.null(dots[["no-check-vignettes"]])) {
+        handleCheck("Checking vignette directory...")
+        checkVignetteDir(package_dir, checkingDir)
+        if ("build-output-file" %in% names(dots)) {
+            handleCheck(
+                "Checking whether vignette is built with 'R CMD build'..."
+            )
+            checkIsVignetteBuilt(package_dir, dots[["build-output-file"]])
         }
     }
 
     if (is.null(dots[["no-check-library-calls"]])){
-        handleCheck("Checking library calls...")
-        checkLibraryCalls(package_dir)
+        handleCheck("Checking package installation calls in R code...")
+        checkPkgInstallCalls(package_dir)
     }
 
     parsedCode <- parseFiles(package_dir)
@@ -272,16 +260,16 @@ BiocCheck <- function(package=".", ...)
     if (is.null(dots[["no-check-CRAN"]]))
     {
         handleCheck("Checking if package already exists in CRAN...")
-        checkIsPackageAlreadyInRepo(package_name, "CRAN")
+        checkIsPackageNameAlreadyInUse(package_name, "CRAN")
     }
 
     if (!is.null(dots[["new-package"]]))
     {
         handleCheck("Checking if new package already exists in Bioconductor...")
-        checkIsPackageAlreadyInRepo(package_name, "BioCsoft")
-        checkIsPackageAlreadyInRepo(package_name, "BioCann")
-        checkIsPackageAlreadyInRepo(package_name, "BioCexp")
-        checkIsPackageAlreadyInRepo(package_name, "BioCworkflows")
+        checkIsPackageNameAlreadyInUse(package_name, "BioCsoft")
+        checkIsPackageNameAlreadyInUse(package_name, "BioCann")
+        checkIsPackageNameAlreadyInUse(package_name, "BioCexp")
+        checkIsPackageNameAlreadyInUse(package_name, "BioCworkflows")
     }
 
     if (is.null(dots[["no-check-bioc-help"]]))
