@@ -113,6 +113,14 @@ checkRemotesUsage <- function(pkgdir)
         handleError("Package dependencies must be on CRAN or Bioconductor. Remove 'Remotes:' from DESCRIPTION")
 }
 
+checkLazyDataUsage <- function(pkgdir)
+{
+    dcf <- read.dcf(file.path(pkgdir, "DESCRIPTION"))
+    if ("LazyData" %in% colnames(dcf) &&
+        tools:::str_parse_logic(dcf[, "LazyData"]))
+        handleNote("'LazyData:' in the 'DESCRIPTION' should be set to false or removed")
+}
+
 checkNewPackageVersionNumber <- function(pkgdir)
 {
     dcf <- read.dcf(file.path(pkgdir, "DESCRIPTION"))
@@ -158,6 +166,14 @@ checkVersionNumber <- function(pkgdir)
     }, error=function(e) handleError("Invalid package version"))
 }
 
+.compareVersions <- function(pkgVer, RVer = getRversion()[, 1:2]) {
+    RVer <- as.package_version(paste0(RVer, ".0"))
+    if (pkgVer < RVer)
+        handleNote(
+            sprintf("Update R version dependency from %s to %s.", pkgVer, RVer)
+        )
+}
+
 checkRVersionDependency <- function(package_dir)
 {
     desc <- file.path(package_dir, "DESCRIPTION")
@@ -172,15 +188,7 @@ checkRVersionDependency <- function(package_dir)
             if (nchar(verStr))
             {
                 ver <- as.package_version(verStr)
-                bv <- package_version(sprintf("%s.%s",
-                    getRversion()$major,
-                    getRversion()$minor))
-                if (ver < bv)
-                {
-                    handleWarning(
-                        "Update R version dependency from ", ver, " to ", bv,
-                        ".")
-                }
+                .compareVersions(ver)
             }
         }
     }
@@ -223,6 +231,25 @@ checkIndivFileSizes <- function(pkgdir)
     }
 }
 
+.testRbuildignore <- function(text) {
+    entries <- Filter(nchar,
+        grep("^#", trimws(text), value = TRUE, invert = TRUE)
+    )
+    grepl("\\^*tests\\$*", entries)
+}
+
+checkRbuildignore <- function(pkgdir) {
+    rbuildfile <- file.path(pkgdir, ".Rbuildignore")
+    if (file.exists(rbuildfile)) {
+        rbuild <- readLines(rbuildfile)
+        testIgnore <- .testRbuildignore(rbuild)
+        if (any(testIgnore))
+            handleError(
+                ".Rbuildignore file includes the 'tests' folder."
+            )
+    }
+}
+
 checkBiocViews <- function(pkgdir)
 {
     dirty <- FALSE
@@ -349,7 +376,7 @@ checkBiocViews <- function(pkgdir)
     }
 }
 
-.checkORCID <- function(orcid) 
+.checkORCID <- function(orcid)
 {
     re <- "^[0-9]{4}-[0-9]{4}-[0-9]{4}-[0-9]{3}[0-9X]$"
     grepl(re, orcid)
@@ -590,6 +617,14 @@ checkVignetteDir <- function(pkgdir, checkingDir)
 
     checkVigBiocInst(pkgdir)
 
+    checkVigInstalls(pkgdir)
+
+    checkVigClassUsage(pkgdir)
+
+    checkTFSymbolUsage(pkgdir)
+
+    checkVigSessionInfo(pkgdir)
+
     msg_eval <- checkVigEvalAllFalse(pkgdir)
     if(length(msg_eval) > 0) {
         handleWarning(" Vignette set global option 'eval=FALSE'")
@@ -860,6 +895,109 @@ checkVigBiocInst <- function(pkgdir) {
     }
 }
 
+.BAD_CALLS <- c("biocLite", "install.packages", "install_packages",
+    "update.packages", "install")
+
+
+checkVigInstalls <- function(pkgdir) {
+    vigdir <- file.path(pkgdir, "vignettes", "")
+    vigfiles <- getVigSources(vigdir)
+    viglist <- structure(
+        vector("list", length(vigfiles)), .Names = basename(vigfiles)
+    )
+    for (vfile in vigfiles) {
+        tempR <- tempfile(fileext=".R")
+        knitr::purl(input = vfile, output = tempR, quiet = TRUE)
+        tokens <- getParseData(parse(tempR, keep.source = TRUE))
+        isBadCall <- tokens[, "token"] == "SYMBOL_FUNCTION_CALL" &
+            tokens[, "text"] %in% .BAD_CALLS
+        tokens <- tokens[isBadCall, , drop = FALSE]
+        viglist[[basename(vfile)]] <- sprintf(
+            "%s (code line %d, column %d)",
+            getDirFile(vfile), tokens[,"line1"], tokens[,"col1"]
+        )
+    }
+    viglist <- Filter(length, viglist)
+    if (length(viglist)) {
+        handleError("Installation calls found in vignette(s)")
+        handleMessage("Found in file(s):", indent=6)
+        invisible(lapply(viglist, function(x) {
+            for (msg in x)
+                handleMessage(msg, indent=8)
+            }
+        ))
+    }
+}
+
+checkVigClassUsage <- function(pkgdir) {
+    vigdir <- file.path(pkgdir, "vignettes", "")
+    vigfiles <- getVigSources(vigdir)
+    viglist <- structure(
+        vector("list", length(vigfiles)), .Names = basename(vigfiles)
+    )
+    for (vfile in vigfiles) {
+        tempR <- tempfile(fileext=".R")
+        knitr::purl(input = vfile, output = tempR, quiet = TRUE)
+        tokens <- getClassNEEQLookup(tempR)
+        viglist[[basename(vfile)]] <- sprintf(
+            "%s (code line %d, column %d)",
+            basename(vfile), tokens[,"line1"], tokens[,"col1"]
+        )
+    }
+    viglist <- Filter(length, viglist)
+    if (length(viglist)) {
+        handleWarning(
+            " Avoid class membership checks with class() / is() and == / !=",
+            "; Use is(x, 'class') for S4 classes"
+        )
+        handleMessage("Found in file(s):", indent=6)
+        invisible(lapply(viglist, function(x) {
+            for (msg in x)
+                handleMessage(msg, indent=8)
+            }
+        ))
+    }
+}
+
+checkTFSymbolUsage <- function(pkgdir) {
+    viglist <- findSymbolsInVignettes(pkgdir, c("T", "F"), "SYMBOL")
+    if (length(viglist)) {
+        handleWarning(
+            " Avoid T/F variables; If logical, use TRUE/FALSE"
+        )
+        handleMessage("Found in file(s):", indent=6)
+        invisible(lapply(viglist, function(x) {
+            for (msg in x)
+                handleMessage(msg, indent=8)
+            }
+        ))
+    }
+}
+
+checkVigSessionInfo <- function(pkgdir) {
+    vigdir <- file.path(pkgdir, "vignettes", "")
+    vigfiles <- getVigSources(vigdir)
+    notFoundVig <- structure(
+        vector("logical", length(vigfiles)), .Names = vigfiles
+    )
+    for (vfile in vigfiles) {
+        pc <- structure(
+            list(parseFile(vfile, pkgdir)), .Names = vfile
+        )
+        res <- findSymbolsInParsedCode(
+            pc, c("sessionInfo", "session_info"), "SYMBOL_FUNCTION_CALL"
+        )
+        if (!length(res)) {
+            notFoundVig[[vfile]] <- TRUE
+        }
+    }
+    if (any(notFoundVig)) {
+        handleNote(" 'sessionInfo' not found in vignette(s)")
+        handleMessage("Missing from file(s):", indent=6)
+        handleMessage(getDirFile(vigfiles[notFoundVig]), indent=8)
+    }
+}
+
 checkIsVignetteBuilt <- function(package_dir, build_output_file)
 {
     if (!file.exists(build_output_file))
@@ -876,25 +1014,53 @@ checkIsVignetteBuilt <- function(package_dir, build_output_file)
     }
 }
 
-checkLibraryCalls <- function(pkgdir)
+.BAD_INSTALL_CALLS <- c("biocLite", "install.packages", "install_packages",
+    "update.packages", "install")
+
+findSymbolsInRFiles <-
+    function(pkgdir, Symbols, tokenType, fun = TRUE)
 {
-    pkgdir <- file.path(pkgdir, "R")
-    rfiles <- dir(
-        pkgdir, ignore.case = TRUE, pattern="\\.R$", full.names=TRUE
+    rfiles <- getRSources(pkgdir)
+    parsedCodes <- lapply(
+        structure(rfiles, .Names = rfiles), parseFile, pkgdir = pkgdir
     )
-    badCalls <- c("biocLite", "install.packages", "update.packages", "install")
-    msg_installs <- lapply(rfiles, function(rfile){
-        tokens <- getParseData(parse(rfile, keep.source=TRUE))
-        tokens <- tokens[tokens[,"text"] %in% badCalls, , drop = FALSE]
-        sprintf("%s: %d", basename(rfile), tokens[,"line1"])
-    })
-    msg_installs <- unlist(msg_installs)
-    if (length(msg_installs) > 0) {
+    msg_res <- findSymbolsInParsedCode(
+        parsedCodes, Symbols, tokenType, fun = fun
+    )
+    unlist(msg_res)
+}
+
+findSymbolsInVignettes <-
+    function(pkgdir, Symbols, tokenType)
+{
+    vigdir <- file.path(pkgdir, "vignettes", "")
+    vigfiles <- getVigSources(vigdir)
+    viglist <- structure(
+        vector("list", length(vigfiles)), .Names = vigfiles
+    )
+    for (vfile in vigfiles) {
+        tempR <- tempfile(fileext=".R")
+        knitr::purl(input = vfile, output = tempR, quiet = TRUE)
+        tokens <- .getTokenTextCode(parseFile(tempR), tokenType, Symbols)
+        viglist[[basename(vfile)]] <- sprintf(
+            "%s (code line %d, column %d)",
+           getDirFile(vfile), tokens[,"line1"], tokens[,"col1"]
+        )
+    }
+    Filter(length, viglist)
+}
+
+checkPkgInstallCalls <- function(package_dir, badCalls = .BAD_INSTALL_CALLS) {
+    msg_installs <- findSymbolsInRFiles(
+        package_dir, badCalls, "SYMBOL_FUNCTION_CALL"
+    )
+    if (length(msg_installs)) {
         handleNote(
-            "install, biocLite, install.packages, or update.packages found in R files"
+            "install, biocLite, install.packages,",
+            " or update.packages found in R files"
         )
         for (msg in msg_installs)
-            handleMessage(msg)
+            handleMessage(msg, indent = 8)
     }
 }
 
@@ -956,28 +1122,43 @@ checkCodingPractice <- function(pkgdir, parsedCode, package_name)
             handleMessage(msg, indent=8)
     }
 
+    # message(paste(...))
+    msg_mp <- checkPasteInSignaler(Rdir)
+    if (length(msg_mp)) {
+        handleNote(" Avoid the use of 'paste' in condition signals")
+        handleMessage("Found in files:", indent=6)
+        for (msg in msg_mp)
+            handleMessage(msg, indent=8)
+    }
+
+    # stop("Error: ")
+    msg_ss <- checkSignalerInSignaler(Rdir)
+    if (length(msg_ss)) {
+        handleNote(" Avoid redundant 'stop' and 'warn*' in signal conditions")
+        handleMessage("Found in files:", indent=6)
+        for (msg in msg_ss)
+            handleMessage(msg, indent=8)
+    }
+
     # T/F
-    res <- checkLogicalUseFiles(pkgdir)
-    pkgname <- basename(pkgdir)
-    res2 <- findLogicalRdir(pkgname, c("T","F"))
-    if (length(c(res,res2)) > 0 ){
-        handleWarning(" Use TRUE/FALSE instead of T/F")
-        if (length(res2) > 0){
-            handleMessage("Found in R/ directory functions:", indent=6)
-            for (msg in res2)
-                handleMessage(msg, indent=8)
-        }
-        if (length(res) > 0){
-            handleMessage("Found in files:", indent=6)
-            for (msg in res)
-                handleMessage(msg, indent=8)
-        }
+    msg_tf <- findSymbolsInRFiles(pkgdir, c("T", "F"), "SYMBOL")
+    if (length(msg_tf)) {
+        handleWarning(
+            " Avoid T/F variables; If logical, use TRUE/FALSE (found ",
+            length(msg_tf),
+            " times)"
+        )
+        for (msg in msg_tf)
+            handleMessage(msg, indent = 8)
     }
 
     # class() ==
-    msg_class <- checkClassEqUsage(pkgdir)
+    msg_class <- checkClassNEEQLookup(pkgdir)
     if (length(msg_class) > 0) {
-        handleWarning(" Avoid class() == or class() != ; use is() or !is()")
+        handleWarning(
+            " Avoid class membership checks with class() / is() and == / !=",
+            "; Use is(x, 'class') for S4 classes"
+        )
         handleMessage("Found in files:", indent=6)
         for (msg in msg_class)
             handleMessage(msg, indent=8)
@@ -992,12 +1173,22 @@ checkCodingPractice <- function(pkgdir, parsedCode, package_name)
             handleMessage(msg, indent=8)
     }
 
+    # external data
+    msg_eda <- checkExternalData(Rdir)
+    if (length(msg_eda)) {
+        handleError(" Avoid references to external hosting platforms")
+        handleMessage("Found in files:", indent=6)
+        for (msg in msg_eda)
+            handleMessage(msg, indent=8)
+    }
+
     # set.seed
-    res <- findLogicalRdir(pkgname, "set.seed")
-    if (length(res) > 0){
-        handleWarning(" Remove set.seed usage in R code")
-        handleMessage("Found in R/ directory functions:", indent=6)
-        for (msg in res)
+    msg_seed <- findSymbolsInRFiles(pkgdir, "set.seed", "SYMBOL_FUNCTION_CALL")
+    if (length(msg_seed)){
+        handleWarning(
+            " Remove set.seed usage (found ", length(msg_seed), " times)"
+        )
+        for (msg in msg_seed)
             handleMessage(msg, indent=8)
     }
 
@@ -1007,37 +1198,67 @@ checkCodingPractice <- function(pkgdir, parsedCode, package_name)
     checkForDirectSlotAccess(parsedCode, package_name)
 
     # browser() calls
-    res <- findSymbolInParsedCode(parsedCode, package_name, "browser",
-                                  "SYMBOL_FUNCTION_CALL")
-    if (res > 0)
-        handleWarning("Remove browser() statements (found in ", res, " files)")
+    msg_b <- findSymbolsInRFiles(pkgdir, "browser", "SYMBOL_FUNCTION_CALL")
+    if (length(msg_b)) {
+        handleWarning(
+            "Remove browser() statements (found ", length(msg_b), " times)")
+        for (msg in msg_b)
+            handleMessage(msg, indent = 8)
+    }
 
+    # install() / install.packages() calls
+    msg_inst <- findSymbolsInRFiles(
+        pkgdir, c("install", "install.packages"), "SYMBOL_FUNCTION_CALL"
+    )
+    if (length(msg_inst)) {
+        handleError(
+            "Remove install() calls (found ", length(msg_inst), " times)"
+        )
+        for (msg in msg_inst)
+            handleMessage(msg, indent = 8)
+    }
 
     # <<-
-    res <- findSymbolInParsedCode(parsedCode, package_name, "<<-",
-                                  "LEFT_ASSIGN")
-    if (res > 0)
-        handleNote("Avoid '<<-' if possible (found in ", res, " files)")
+    msg_da <- findSymbolsInRFiles(pkgdir, "<<-", "LEFT_ASSIGN")
+    if (length(msg_da)) {
+        handleNote("Avoid '<<-' if possible (found ", length(msg_da), " times)")
+        for (msg in msg_da)
+            handleMessage(msg, indent = 8)
+    }
 
+    # Sys.setenv calls
+    msg_env <- findSymbolsInRFiles(pkgdir, "Sys.setenv", "SYMBOL_FUNCTION_CALL")
+    if (length(msg_env)) {
+        handleError("Avoid 'Sys.setenv' (found ", length(msg_env), " times)")
+        for (msg in msg_env)
+            handleMessage(msg, indent = 8)
+    }
+
+    # suppressWarnings/Messages calls
+    msg_supp <- findSymbolsInRFiles(
+        pkgdir,
+        c("suppressWarnings", "suppressMessages"),
+        "SYMBOL_FUNCTION_CALL"
+    )
+    if (length(msg_supp)) {
+        handleNote(
+            "Avoid 'suppressWarnings'/'*Messages' if possible (found ",
+            length(msg_supp), " times)"
+        )
+        for (msg in msg_supp)
+            handleMessage(msg, indent = 8)
+    }
 }
 
-checkSapply <- function(Rdir){
-
-    rfiles <- dir(Rdir, ignore.case = TRUE, pattern="\\.R$", full.names=TRUE)
-    msg_sapply <- lapply(rfiles, function(rfile){
-        tokens <- getParseData(parse(rfile, keep.source=TRUE))
-        tokens <- tokens[tokens[,"text"] == "sapply", ,drop=FALSE]
-        sprintf(
-            "%s (line %d, column %d)",
-            basename(rfile), tokens[,"line1"], tokens[,"col1"]
-        )
-    })
-    msg_sapply <- unlist(msg_sapply)
+checkSapply <- function(Rdir) {
+    msg_sapply <- findSymbolsInRFiles(
+        dirname(Rdir), "sapply", "SYMBOL_FUNCTION_CALL", FALSE
+    )
 }
 
 check1toN <- function(Rdir){
 
-    rfiles <- dir(Rdir, ignore.case = TRUE, pattern="\\.R$", full.names=TRUE)
+    rfiles <- getRSources(Rdir)
     msg_seq <- lapply(rfiles, function(rfile) {
         tokens <- getParseData(parse(rfile, keep.source=TRUE))
         tokens <- tokens[tokens[,"token"] != "expr", ,drop=FALSE]
@@ -1055,7 +1276,7 @@ check1toN <- function(Rdir){
 
 checkSingleColon <- function(Rdir, avail_pkgs = character(0L)) {
 
-    rfiles <- dir(Rdir, pattern = "\\.[Rr]$", full.names = TRUE)
+    rfiles <- getRSources(Rdir)
     names(rfiles) <- basename(rfiles)
     colon_pres <- lapply(rfiles, function(rfile) {
         tokens <- getParseData(parse(rfile, keep.source = TRUE))
@@ -1078,24 +1299,117 @@ checkSingleColon <- function(Rdir, avail_pkgs = character(0L)) {
     msg_sc <- unlist(msg_sc)
 }
 
-checkClassEqUsage <- function(pkgdir){
+.filtTokens <-
+    function(ind, tokens, keywords = c("paste0", "paste"))
+{
+    txt <- tokens[ind, "text"]
+    filt <- tolower(txt) %in% keywords
+    #filt <- grepl(txt, keywords, ignore.case = ignore.case)
+    if (any(filt) && "collapse" %in% txt)
+        filt <- FALSE
+    ind[filt]
+}
 
-    regex <- "\\bclass\\s*(.*)\\s*[!=]="
-    pkgdir <- sprintf("%s%s", pkgdir, .Platform$file.sep)
-    # Limit to R files and vignette source files
-    Rdir <- sprintf("%s%s%s", pkgdir, "R", .Platform$file.sep)
-    fnd1 <-
-        if(dir.exists(Rdir)){
-            grepPkgDir(Rdir, paste0('-rHn "', regex, '"'),
-                       full_path=TRUE)
-        } else {
-            character(0)
-        }
-    VigFiles <- getVigSources(sprintf("%s%s", pkgdir,"vignettes"))
-    fnd2 <- unlist(lapply(VigFiles,
-                          FUN=grepPkgDir, paste0('-rHn "', regex, '"'),
-                          full_path=TRUE))
-    msg_sys <- sub(c(fnd1, fnd2), pattern=pkgdir, replacement="", fixed=TRUE)
+.getTokens <- function(rfile) {
+    tokens <- getParseData(parse(rfile, keep.source = TRUE))
+    tokens[tokens[,"token"] != "expr", ,drop=FALSE]
+}
+
+.findSignalerRanges <- function(rfile, tokens) {
+    txt <- tokens[, "text"]
+    signalers <- which(
+        txt %in% c("message", "warning", "stop") &
+        tokens[, "token"] == "SYMBOL_FUNCTION_CALL"
+    )
+    opar <- which(txt == "(")
+    startSig <- vapply(signalers, function(x) min(opar[opar > x]), numeric(1L))
+    parnum <- tokens[startSig, "parent"]
+    endSig <- nrow(tokens) - match(parnum, rev(tokens[, "parent"]))
+    Map(seq, startSig, endSig)
+}
+
+.findInSignaler <- function(rfile, FUN, ...) {
+    tokens <- .getTokens(rfile)
+    sigRanges <- .findSignalerRanges(rfile, tokens)
+    pasteInd <- lapply(sigRanges, FUN, tokens = tokens, ...)
+    tokens <- tokens[unlist(pasteInd), , drop = FALSE]
+    rfile <- paste0("R/", basename(rfile))
+    sprintf(
+        "%s (line %d, column %d)",
+        rfile, tokens[, "line1"], tokens[, "col1"]
+    )
+}
+
+.findPasteInSignaler <- function(rfile) {
+    .findInSignaler(rfile, .filtTokens)
+}
+
+.grepTokens <-
+    function(ind, tokens, keywords)
+{
+    txt <- tokens[ind, , drop = FALSE]
+    strs <- txt$token == "STR_CONST"
+    ind <- ind[strs]
+    txt <- txt[strs, "text"]
+    filt <- grepl(paste0(keywords, collapse = "|"), txt, ignore.case = TRUE)
+    ind[filt]
+}
+
+.findSignalerInSignaler <- function(rfile) {
+    .findInSignaler(rfile, .grepTokens,
+        keywords = c("message", "warn", "error"))
+}
+
+checkPasteInSignaler <- function(Rdir) {
+    rfiles <- getRSources(Rdir)
+    pasteSig <- lapply(rfiles, .findPasteInSignaler)
+    pasteSig <- unlist(pasteSig)
+}
+
+checkSignalerInSignaler <- function(Rdir) {
+    rfiles <- getRSources(Rdir)
+    sisig <- lapply(rfiles, .findSignalerInSignaler)
+    sisig <- unlist(sisig)
+}
+
+.checkValidNEEQPattern <- function(tokens, eqnums) {
+    tokens[["rowID"]] <- seq_len(nrow(tokens))
+    unlist(lapply(eqnums, function(eq) {
+        parnum <- tokens[eq, "parent"]
+        hits <- which(tokens[, "parent"] %in% parnum)
+        if (!length(hits)) { return(NULL) }
+        startEQ <- min(hits)
+        endEQ <- max(hits)
+        EQblock <- tokens[startEQ:endEQ, ]
+        hasIS <- EQblock[, "token"] == "SYMBOL_FUNCTION_CALL" &
+            EQblock[, "text"] %in% c("is", "class")
+        if (any(hasIS) && "STR_CONST" %in% EQblock[EQblock[["rowID"]] > eq, "token"])
+            eq
+        else
+            NULL
+    }))
+}
+
+getClassNEEQLookup <- function(rfile) {
+    tokens <- getParseData(parse(rfile, keep.source = TRUE))
+    eqtoks <- which(tokens[, "token"] %in% c("NE", "EQ"))
+    eqtoks <- .checkValidNEEQPattern(tokens, eqtoks)
+    tokens[eqtoks, , drop = FALSE]
+}
+
+checkClassNEEQLookup <- function(pkgdir) {
+    rfiles <- getRSources(pkgdir)
+    names(rfiles) <- basename(rfiles)
+    NEEQ_pres <- lapply(rfiles, getClassNEEQLookup)
+    NEEQ_pres <- Filter(nrow, NEEQ_pres)
+    msg_neeq <- lapply(names(NEEQ_pres), function(rfile, framelist) {
+        tokens <- framelist[[rfile]]
+        sprintf(
+            "%s (line %d, column %d)",
+            rfile, tokens[, "line1"], tokens[, "col1"]
+        )
+    }, framelist = NEEQ_pres)
+    unlist(msg_neeq)
 }
 
 checkSystemCall <- function(pkgdir){
@@ -1104,6 +1418,27 @@ checkSystemCall <- function(pkgdir){
     msg_sys <- grepPkgDir(pkgdir, "-rHn '^system(.*'")
 }
 
+checkExternalData <- function(Rdir) {
+
+    rfiles <- getRSources(Rdir)
+    msg_eda <- lapply(rfiles, function(rfile) {
+        tokens <- getParseData(parse(rfile, keep.source=TRUE))
+        tokens <- tokens[tokens[,"token"] == "STR_CONST", ,drop=FALSE]
+
+        platforms <- "githubusercontent|github|gitlab|bitbucket|dropbox"
+        txtkns <- tokens[, "text"]
+        hits <- grepl(platforms, txtkns, ignore.case = TRUE) &
+            grepl("dl|\\.\\w+\"$", txtkns)
+        tokens <- tokens[hits, , drop = FALSE]
+
+        sprintf(
+            "%s (line %d, column %d)",
+            basename(rfile), tokens[,"line1"], tokens[,"col1"]
+        )
+    })
+    unlist(msg_eda)
+}
+
 
 checkForDirectSlotAccess <- function(parsedCode, package_name)
 {
@@ -1118,8 +1453,6 @@ checkForDirectSlotAccess <- function(parsedCode, package_name)
     }
 }
 
-
-
 checkFunctionLengths <- function(parsedCode, pkgname)
 {
     df <- data.frame(stringsAsFactors=FALSE)
@@ -1439,19 +1772,20 @@ checkUnitTests <- function(pkgdir)
 ## check if testthat contains skip_on_bioc() and throw note of it does
 checkSkipOnBioc <- function(pkgdir)
 {
-    pkgdir <- file.path(pkgdir, "tests", "testthat")
-    if (file.exists(pkgdir)) {
-        testfiles <- list.files(pkgdir, pattern = ".R$")
-        testfiles_full <- file.path(pkgdir, testfiles)
-        msg <- lapply(seq_along(testfiles), function(idx){
-            tokens <- getParseData(parse(testfiles_full[idx], keep.source=TRUE))
-            if ("skip_on_bioc" %in% unlist(tokens))
-                testfiles[idx]
-        })
-        msg <- paste(unlist(msg), collapse = " ")
-        if (msg != "") {
-            handleNote("skip_on_bioc() found in testthat files: ", msg)
-        }
+    testdir <- file.path(pkgdir, "tests", "testthat")
+    if (!file.exists(testdir))
+        return()
+
+    testfiles <- dir(testdir, pattern = "\\.[Rr]$", full.names = TRUE)
+    msg <- vapply(testfiles, function(testfile){
+        tokens <- getParseData(parse(testfile, keep.source=TRUE))
+        if ("skip_on_bioc" %in% unlist(tokens)) {
+            basename(testfile)
+        } else NA_character_
+    }, character(1))
+    msg <- paste(msg[!is.na(msg)], collapse = " ")
+    if (nzchar(msg)) {
+        handleNote("skip_on_bioc() found in testthat files: ", msg)
     }
 }
 
@@ -1536,11 +1870,25 @@ checkFormatting <- function(pkgdir, nlines=6)
     }
 }
 
-checkIsPackageAlreadyInRepo <- function(pkgName, repo=c("CRAN", "BioCsoft",
+checkIsPackageNameAlreadyInUse <- function(pkgName, repo=c("CRAN", "BioCsoft",
                                                      "BioCann", "BioCexp", "BioCworkflows"))
 {
     repo <- match.arg(repo)
-    repo.url <- sprintf("%s/src/contrib/PACKAGES", BiocManager::repositories()[repo])
+
+    if (repo == "CRAN"){
+        repo.url <- sprintf("%s/src/contrib/PACKAGES", BiocManager::repositories()[repo])
+    }else{
+        repo.url <- switch(repo,
+                           BiocSoft = "http://bioconductor.org/packages/devel/bioc/VIEWS",
+                           BioCann =
+                               "http://bioconductor.org/packages/devel/data/annotation/VIEWS",
+                           BioCexp =
+                               "http://bioconductor.org/packages/devel/data/experiment/VIEWS",
+                           BioCworkflows =
+                               "http://bioconductor.org/packages/devel/workflows/VIEWS",
+                           "http://bioconductor.org/packages/devel/bioc/VIEWS")
+    }
+
     conn <- url(repo.url)
     dcf <- tryCatch(suppressWarnings(read.dcf(conn)), error=identity)
     close(conn)
@@ -1613,17 +1961,49 @@ checkForSupportSiteRegistration <- function(package_dir)
         handleMessage("Maintainer email is ok.")
         return()
     }
+    accountExists <- checkSupportReg(email)
+
+    if (accountExists){
+        pkgname <- tolower(basename(package_dir))
+        checkWatchedTag(email, pkgname)
+    }
+}
+
+checkSupportReg <- function(email){
+
     url <- paste0("https://support.bioconductor.org/api/email/", email, "/")
     response <- tryCatch(GET(url), error=identity)
     if (inherits(response, "error")) {
         handleMessage(
             "Unable to connect to support site:",
             "\n  ", conditionMessage(response))
+        FALSE
     } else if (suppressMessages(content(response))) {
         handleMessage("Maintainer is registered at support site.")
+        TRUE
     } else {
         handleError("Maintainer must register at the support site; ",
-            "visit https://support.bioconductor.org/accounts/signup/ .")
+                    "visit https://support.bioconductor.org/accounts/signup/ .")
+        FALSE
+    }
+}
+
+checkWatchedTag <- function(email, pkgname){
+
+    url <- paste0("https://support.bioconductor.org/api/watched/tags/", email, "/")
+    response <- tryCatch(GET(url), error=identity)
+    if (inherits(response, "error")) {
+        handleMessage(
+            "Unable to connect to support site:",
+            "\n  ", conditionMessage(response))
+    } else {
+        tags<-tolower(trimws(unlist(strsplit(content(response)$watched_tags, split=","))))
+        if (tolower(pkgname) %in% tags){
+            handleMessage("Package name is in support site watched tags.")
+        }else{
+            handleError("Maintainer must add package name to Watched Tags on the support site; ",
+                        "Edit your Support Site User Profile to add Watched Tags.")
+        }
     }
 }
 
@@ -1665,6 +2045,44 @@ checkBadFiles <- function(package_dir){
     }
 }
 
+.checkLicenseForRestrictiveUse <- function(license) {
+    handleCheck("Checking License: for restrictive use...")
+
+    if (length(license) != 1L || is.na(license)) {
+        handleNote("malformed 'License:' field '", license, "'")
+        return(invisible())
+    }
+    ldb_file <- file.path(R.home("share"), "licenses", "license.db")
+    if (!file.exists(ldb_file)) {
+        handleNote(
+            "license database not found. ",
+            "Expected location: '", ldb_file, "'. ",
+            "License: '", license, "'"
+        )
+        return(invisible())
+    }
+    licenses <- read.dcf(ldb_file)
+    sss <- licenses[, "SSS"]
+    abbrev <- licenses[, "Abbrev"]
+    abbrev[!is.na(sss)] <- sss[!is.na(sss)]
+    restrict <- licenses[, "Restricts_use"]
+    idx <- (restrict == "yes") & !is.na(restrict) & !is.na(abbrev)
+
+    ## PCAN/DESCRIPTION:License: CC BY-NC-ND 4.0
+    ## QUBIC/DESCRIPTION:License: CC BY-NC-ND 4.0 + file LICENSE
+    test0 <- any(vapply(abbrev[idx], grepl, logical(1), license, fixed = TRUE))
+    test1 <-
+        !any(vapply(
+             abbrev[!is.na(abbrev)], grepl, logical(1), license, fixed = TRUE
+         ))
+    if (test0) {
+        handleError("License '", license, "' restricts use")
+    } else if (test1) {
+        handleNote(
+            "License '", license, "' unknown; licenses cannot restrict use"
+        )
+    }
+}
 
 checkDescription <- function(package_dir){
 
@@ -1685,6 +2103,12 @@ checkDescription <- function(package_dir){
     }
 }
 
+checkDESCRIPTIONFile <- function(package_dir) {
+    dcf <- read.dcf(file.path(package_dir, "DESCRIPTION"))
+
+    .checkLicenseForRestrictiveUse(dcf[,"License"])
+}
+
 checkForCitationFile <- function(package_dir) {
     citfile_location <- file.path(package_dir, "inst", "CITATION")
     if(file.exists(citfile_location)) {
