@@ -122,8 +122,8 @@ test_vignettes0 <- function()
     BiocCheck:::checkVignetteDir(pkgdir, TRUE)
     checkTrue(.error$getNum() == 0
         && .warning$getNum() == 1
-        && .note$getNum() == 0,
-        "expected 1 warnings")
+        && .note$getNum() == 1,
+        "expected 1 warning and 1 note")
     .zeroCounters()
 
     # test OK
@@ -132,8 +132,9 @@ test_vignettes0 <- function()
     BiocCheck:::checkVignetteDir(pkgdir, TRUE)
     checkTrue(.error$getNum() == 0
         && .warning$getNum() == 0
-        && .note$getNum() == 0,
-        "expected no notes/error/warning")
+        && .note$getNum() == 1,
+        "expected 1 note and 0 errors/warnings")
+    .zeroCounters()
 
 
     # check rnw file in inst/doc  WARNING
@@ -185,9 +186,9 @@ test_vignettes0 <- function()
     # 2 WARNINGS - vignette template and evaluate more chunks
     BiocCheck:::checkVignetteDir(system.file("testpackages",
         "testpkg0", package="BiocCheck"), TRUE)
-    checkEquals(4, .warning$getNum())
+    checkEquals(7, .warning$getNum())
     checkEquals("Evaluate more vignette chunks.",
-        .warning$get()[4])
+        .warning$get()[5])
     checkTrue(grepl(pattern="VignetteIndex",  .warning$get()[3]))
     .zeroCounters()
 
@@ -197,7 +198,7 @@ test_vignettes0 <- function()
     checkEquals(2, .error$getNum())
     checkTrue(grepl(pattern="VignetteBuilder",  .error$get()[1]))
     checkTrue(grepl(pattern="VignetteEngine",  .error$get()[2]))
-    checkEquals(3, .warning$getNum())
+    checkEquals(4, .warning$getNum())
     checkTrue(grepl(pattern="missing Vignette metadata",  .warning$get()[1]))
     checkTrue(grepl(pattern="not currently Suggested",  .warning$get()[2]))
     checkTrue(grepl(pattern="Evaluate more vignette chunks",  .warning$get()[3]))
@@ -231,6 +232,11 @@ test_checkVersionNumber <- function()
     }
     BiocCheck:::checkVersionNumber(UNIT_TEST_TEMPDIR)
     checkTrue(.warning$getNum() ==1)
+    .zeroCounters()
+    BiocCheck:::.compareVersions(
+        as.package_version("4.0"), as.package_version("4.1")
+    )
+    checkTrue(.note$getNum() ==1)
 }
 
 test_checkNewPackageVersionNumber <- function()
@@ -258,6 +264,20 @@ test_checkNewPackageVersionNumber <- function()
     checkTrue(stillZero())
 }
 
+test_checkRbuildignore <- function()
+{
+    rbuildfile <- file.path(UNIT_TEST_TEMPDIR, ".Rbuildignore")
+    cat("tests/", "tests", "^tests$", ".*/testthat",
+        sep = "\n", file = rbuildfile
+    )
+    checkTrue(
+        identical(
+            sum(BiocCheck:::.testRbuildignore(readLines(rbuildfile))),
+            3L
+        )
+    )
+}
+
 test_checkBiocViews <- function()
 {
     .zeroCounters()
@@ -306,6 +326,28 @@ test_badFiles <- function(){
     unlink(pkgdir)
 }
 
+test_checkLicenseForRestrictiveUse <- function() {
+    .zeroCounters()
+    BiocCheck:::.checkLicenseForRestrictiveUse("GPL-3.0")
+    stillZero()
+
+    .zeroCounters()
+    BiocCheck:::.checkLicenseForRestrictiveUse("CC BY-NC-ND 4.0")
+    checkEquals(1, .error$getNum())
+
+    .zeroCounters()
+    BiocCheck:::.checkLicenseForRestrictiveUse("CC BY-NC-ND 4.0 + file LICENSE")
+    checkEquals(1, .error$getNum())
+
+    .zeroCounters()
+    BiocCheck:::.checkLicenseForRestrictiveUse("UNKNOWN")
+    checkEquals(1, .note$getNum())
+
+    .zeroCounters()
+    BiocCheck:::.checkLicenseForRestrictiveUse(NA_character_)
+    checkEquals(1, .note$getNum())
+}
+
 test_checkBBScompatibility <- function()
 {
     pkgdir <- UNIT_TEST_TEMPDIR
@@ -313,14 +355,23 @@ test_checkBBScompatibility <- function()
         dir.create(pkgdir)
 
 
-    cat("Package : foo", file=file.path(UNIT_TEST_TEMPDIR, "DESCRIPTION"))
+    cat("Package : foo",
+        "License: GPL-2",
+        sep = "\n",
+        file=file.path(UNIT_TEST_TEMPDIR, "DESCRIPTION")
+    )
     BiocCheck:::checkBBScompatibility(UNIT_TEST_TEMPDIR, FALSE)
     checkError("Space in DESCRIPTION field name doesn't cause error")
     .zeroCounters()
 
 
-    cat("Package: foo\n\nImports: bar", file=file.path(UNIT_TEST_TEMPDIR,
-        "DESCRIPTION"))
+    cat("Package: foo",
+        "",
+        "Imports: bar",
+        "License: GPL-2",
+        sep = "\n",
+        file=file.path(UNIT_TEST_TEMPDIR, "DESCRIPTION")
+    )
     BiocCheck:::checkBBScompatibility(UNIT_TEST_TEMPDIR, FALSE)
     checkError("Blank line in DESCRIPTION doesn't cause error")
     .zeroCounters()
@@ -339,6 +390,7 @@ test_checkBBScompatibility <- function()
         "Description: This is a test description field in the Foo package.",
         "  The field should contain two sentences and it should trigger a",
         "  NOTE in the check.",
+        "License: GPL-2",
         sep = "\n",
         file = file.path(UNIT_TEST_TEMPDIR, "DESCRIPTION")
     )
@@ -348,79 +400,125 @@ test_checkBBScompatibility <- function()
         "Note"
     )
 
-    cat("Package: Foo", file=file.path(UNIT_TEST_TEMPDIR, "DESCRIPTION"))
+    cat("Package: Foo",
+        "License: GPL-2",
+        sep = "\n",
+        file=file.path(UNIT_TEST_TEMPDIR, "DESCRIPTION")
+    )
     BiocCheck:::checkBBScompatibility(UNIT_TEST_TEMPDIR, FALSE)
     checkError("Package name which doesn't match dir name does not cause error!")
 
 
-    cat(sprintf("Package: ", UNIT_TEST_PKG),
+    cat(paste("Package:", UNIT_TEST_PKG),
+        "License: GPL-2",
+        sep = "\n",
         file=file.path(UNIT_TEST_TEMPDIR, "DESCRIPTION"))
     BiocCheck:::checkBBScompatibility(UNIT_TEST_TEMPDIR, FALSE)
     checkError("Missing Version doesn't cause error!")
 
 
-    cat(sprintf("Package: %s\nVersion: 0.99.0\nAuthors@R: 1", UNIT_TEST_PKG),
+    cat(paste("Package: ", UNIT_TEST_PKG),
+        "Version: 0.99.0",
+        "Authors@R: 1",
+        "License: GPL-2",
+        sep = "\n",
         file=file.path(UNIT_TEST_TEMPDIR, "DESCRIPTION"))
     .zeroCounters()
     BiocCheck:::checkBBScompatibility(UNIT_TEST_TEMPDIR, FALSE)
     checkError("Wrong class in Authors@R doesn't cause error!")
 
 
-    cat(sprintf("Package: %s\nVersion: 0.99.0\nAuthors@R: c(person('Bioconductor', 'Package Maintainer', email='maintainer@bioconductor.org', role=c('aut')))", UNIT_TEST_PKG),
+    cat(paste("Package:", UNIT_TEST_PKG),
+        "Version: 0.99.0",
+        "Authors@R: c(person('Bioconductor', 'Package Maintainer', email='maintainer@bioconductor.org', role=c('aut')))",
+        "License: GPL-2",
+        sep = "\n",
         file=file.path(UNIT_TEST_TEMPDIR, "DESCRIPTION"))
     .zeroCounters()
     BiocCheck:::checkBBScompatibility(UNIT_TEST_TEMPDIR, FALSE)
     checkError("Missing cre role in Authors@R doesn't cause error!")
 
 
-    cat(sprintf("Package: %s\nVersion: 0.99.0", UNIT_TEST_PKG),
+    cat(sprintf("Package: ", UNIT_TEST_PKG),
+        "Version: 0.99.0",
+        "License: GPL-2",
+        sep = "\n",
         file=file.path(UNIT_TEST_TEMPDIR, "DESCRIPTION"))
     BiocCheck:::checkBBScompatibility(UNIT_TEST_TEMPDIR, FALSE)
     checkError("Missing Maintainer and Authors@R doesn't cause error!")
 
 
-    cat(sprintf("Package: %s\nVersion: 0.99.0\nMaintainer: Joe Blow",
-        UNIT_TEST_PKG),
+    cat(paste("Package:", UNIT_TEST_PKG),
+        "Version: 0.99.0",
+        "Maintainer: Joe Blow",
+        "License: GPL-2",
+        sep = "\n",
         file=file.path(UNIT_TEST_TEMPDIR, "DESCRIPTION"))
     BiocCheck:::checkBBScompatibility(UNIT_TEST_TEMPDIR, FALSE)
     checkTrue(.error$getNum() > 0L, "Missing email in Maintainer doesn't cause error!")
 
 
     .zeroCounters()
-    cat(sprintf("Package: %s\nVersion: 0.99.0\nMaintainer: Joe Blow <joe@blow.com>\nAuthors@R: c(person('Bioconductor', \n  'Package Maintainer', email='maintainer@bioconductor.org', role=c('aut', 'cre')))",
-                UNIT_TEST_PKG),
+    cat(paste("Package:", UNIT_TEST_PKG),
+        "Version: 0.99.0",
+        "Maintainer: Joe Blow <joe@blow.com>",
+        "Authors@R: c(person('Bioconductor Package Maintainer',",
+        "    email='maintainer@bioconductor.org', role=c('aut', 'cre')))",
+        "License: GPL-2",
+        sep = "\n",
         file=file.path(UNIT_TEST_TEMPDIR, "DESCRIPTION"))
     BiocCheck:::checkDescription(UNIT_TEST_TEMPDIR)
     checkTrue(.warning$getNum() == 0L, "Using Maintainer and Authors@R causes warning!")
     checkTrue(.error$getNum() == 1L, "Using Maintainer and Author@R doesn't cause error!")
 
     .zeroCounters()
-    cat(sprintf(
-        "Package: %s\nVersion: 0.99.0\nAuthors@R: c(person('Bioconductor', 'Package Maintainer', email='maintainer@bioconductor.org', comment = c(ORCID = '0000-0000-000-0000'), role=c('aut', 'cre')))",
-                UNIT_TEST_PKG),
+    cat(paste("Package:", UNIT_TEST_PKG),
+        "Version: 0.99.0",
+        "Authors@R: c(person('Bioconductor', 'Package Maintainer',",
+        "    email='maintainer@bioconductor.org',",
+        "    comment = c(ORCID = '0000-0000-000-0000'),",
+        "    role=c('aut', 'cre')))",
+        "License: GPL-2",
+        sep = "\n",
         file=file.path(UNIT_TEST_TEMPDIR, "DESCRIPTION"))
     BiocCheck:::checkBBScompatibility(UNIT_TEST_TEMPDIR, FALSE)
     checkTrue(.note$getNum() == 1L, "An invalid ORCID ID causes a note!")
 
 
     .zeroCounters()
-    cat(sprintf("Package: %s\nVersion: 0.99.0\nMaintainer: Joe Blow <joe@blow.com>",
-        UNIT_TEST_PKG),
+    cat(paste("Package:", UNIT_TEST_PKG),
+        "Version: 0.99.0",
+        "Maintainer: Joe Blow <joe@blow.com>",
+        "License: GPL-2",
+        sep = "\n",
         file=file.path(UNIT_TEST_TEMPDIR, "DESCRIPTION"))
     BiocCheck:::checkBBScompatibility(UNIT_TEST_TEMPDIR, FALSE)
     checkTrue(.error$getNum() > 0L,"Utilize Maintainer instead of Authors@R doesn't cause error!")
 
 
     .zeroCounters()
-    cat(sprintf("Package: %s\nVersion: 0.99.0\nAuthors@R: c(person('Bioconductor', \n  'Package Maintainer', email='maintainer@bioconductor.org', role=c('aut', 'cre')), person('Joe', 'Blow', email='joe@blow.com', role='cre'))",
-        UNIT_TEST_PKG),
+    cat(paste("Package:", UNIT_TEST_PKG),
+        "Version: 0.99.0",
+        "Authors@R: c(",
+        "  person('Bioconductor Package Maintainer',",
+        "    email='maintainer@bioconductor.org',",
+        "    role=c('aut', 'cre')),",
+        "  person('Joe', 'Blow', email='joe@blow.com', role='cre'))",
+        "License: GPL-2",
+        sep = "\n",
         file=file.path(UNIT_TEST_TEMPDIR, "DESCRIPTION"))
     BiocCheck:::checkBBScompatibility(UNIT_TEST_TEMPDIR, FALSE)
     checkError("More than one maintainer doesn't cause error!")
 
     .zeroCounters()
-    cat(sprintf("Package: %s\nVersion: 0.99.0\nAuthors@R: c(person('Bioconductor', \n  'Package Maintainer', email='maintainer@bioconductor.org', role=c('aut', 'cre')))",
-        UNIT_TEST_PKG),
+    cat(paste("Package:", UNIT_TEST_PKG),
+        "Version: 0.99.0",
+        "Authors@R: c(",
+        "  person('Bioconductor Package Maintainer',",
+        "    email='maintainer@bioconductor.org',",
+        "    role=c('aut', 'cre')))",
+        "License: GPL-2",
+        sep = "\n",
         file=file.path(UNIT_TEST_TEMPDIR, "DESCRIPTION"))
     BiocCheck:::checkBBScompatibility(UNIT_TEST_TEMPDIR, FALSE)
     checkTrue(stillZero())
@@ -443,7 +541,7 @@ test_checkUnitTests <- function()
 {
     BiocCheck:::checkUnitTests(UNIT_TEST_TEMPDIR)
     checkTrue(.note$getNum() == 1)
-    dir.create(file.path(UNIT_TEST_TEMPDIR, "tests"))
+    dir.create(file.path(UNIT_TEST_TEMPDIR, "tests"),recursive=TRUE)
     cat("nothing", file=file.path(UNIT_TEST_TEMPDIR, "tests",
         "foo.R"))
     .zeroCounters()
@@ -454,25 +552,51 @@ test_checkUnitTests <- function()
         "testpkg0", package="BiocCheck"))
     checkTrue(.note$getNum() == 1)
     .zeroCounters()
-    BiocCheck:::checkLibraryCalls(system.file("testpackages",
-        "testpkg0", package="BiocCheck"))
-    checkTrue(.note$getNum() == 1)
-    .zeroCounters()
 
     # check coding practice
-    pkgdir = system.file("testpackages", "testpkg0", package="BiocCheck")
-    Rdir = file.path(pkgdir, "R")
+    pkgdir <- system.file("testpackages", "testpkg0", package="BiocCheck")
+    Rdir <- file.path(pkgdir, "R")
     msg_sapply <- BiocCheck:::checkSapply(Rdir)
     checkTrue(length(msg_sapply) == 1)
     msg_seq <- BiocCheck:::check1toN(Rdir)
     checkTrue(length(msg_seq) == 1)
-    msg_sc <- BiocCheck:::checkSingleColon(Rdir)
-    checkTrue(length(msg_sc) == 1)
-    pkgdir = system.file("testpackages", "testpkg2", package="BiocCheck")
-    res <- BiocCheck:::checkLogicalUseFiles(pkgdir)
+    msg_eda <- BiocCheck:::checkExternalData(Rdir)
+    checkTrue(length(msg_eda) == 4)
+    avail_pkgs <- BiocManager::available()
+    msg_sc <- BiocCheck:::checkSingleColon(Rdir, avail_pkgs)
+    testval <- ifelse("BiocCheck" %in% avail_pkgs, 1, 0)
+    checkTrue(length(msg_sc) == testval)
+    pkgdir <- system.file("testpackages", "testpkg2", package="BiocCheck")
+    res <- BiocCheck:::findSymbolsInVignettes(pkgdir, c("T", "F"), "SYMBOL")
     checkTrue(length(res) == 1)
 }
 
+test_findPasteInSignaler <- function() {
+    rfile <- tempfile()
+    writeLines(c(
+        "message(paste('foo', 'bar'))",
+        "message(paste('foo', x))",
+        "message(paste(x, collapse = '\t'))",
+        "message('foo', paste(x, collapse = 't'))"
+    ), rfile)
+    checkTrue(
+        length(BiocCheck:::.findPasteInSignaler(rfile)) == 2L
+    )
+}
+
+test_findSignalerInSignaler <- function() {
+    rfile <- tempfile()
+    writeLines(c(
+        "message('warning: see here')",
+        "warning('error here')",
+        "stop('ErrOR: see here')",
+        "stop('message here')"
+    ), rfile)
+    checkTrue(
+        length(BiocCheck:::.findSignalerInSignaler(rfile)) == 4L
+    )
+}
+
 test_installAndLoad <- function()
 {
     BiocCheck:::installAndLoad(create_test_package('testpkg'))
@@ -495,6 +619,12 @@ test_parseFile <- function()
     cat("1 + 1", file=testFile)
     df <- BiocCheck:::parseFile(testFile, "BiocCheck")
     checkTrue(all(dim(df) == c(6,9)))
+    ## test that  testpkg0_child.Rmd is read in using `child =` chunk
+    ## in testpkg0.Rmd
+    pkgdir <- system.file("testpackages", "testpkg0", package="BiocCheck")
+    testFile <- file.path(pkgdir, "vignettes", "testpkg0.Rmd")
+    incl <- BiocCheck:::parseFile(testFile, pkgdir)
+    checkTrue(all(c("2", "+", "1") %in% incl[, "text"]))
 }
 
 test_checkForBrowser <- function()
@@ -502,43 +632,80 @@ test_checkForBrowser <- function()
     if (is.null(parsedCode))
         parsedCode <- BiocCheck:::parseFiles(system.file("testpackages",
             "testpkg0", package="BiocCheck"))
-    res <- BiocCheck:::findSymbolInParsedCode(parsedCode, "testpkg0", "browser",
+    res <- BiocCheck:::findSymbolsInParsedCode(parsedCode, "browser",
         "SYMBOL_FUNCTION_CALL")
-    checkTrue(res == 1)
+    checkTrue(length(res) == 1)
 }
 
-test_checkClassEqUsage <- function()
+test_checkVigSessionInfo <- function()
+{
+    pkgdir <- system.file("testpackages", "testpkg0", package="BiocCheck")
+    checkVigSessionInfo(pkgdir)
+    checkTrue(.note$getNum() == 1)
+}
+
+test_findSymbolsInRFiles <- function()
+{
+    pkgdir <- system.file("testpackages", "testpkg0",
+        package="BiocCheck", mustWork = TRUE)
+    msg <- BiocCheck:::findSymbolsInRFiles(
+        pkgdir, BiocCheck:::.BAD_INSTALL_CALLS, "SYMBOL_FUNCTION_CALL"
+    )
+    checkTrue(length(msg) == 2)
+}
+
+test_checkVigInstalls <- function()
+{
+    BiocCheck:::checkVigInstalls(
+        system.file("testpackages", "testpkg0", package="BiocCheck", mustWork = TRUE)
+    )
+    checkTrue(.error$getNum() == 1)
+    .zeroCounters()
+}
+
+test_checkVigSessionInfo <- function()
+{
+    BiocCheck:::checkVigSessionInfo(
+        system.file("testpackages", "testpkg0", package = "BiocCheck",
+            mustWork = TRUE)
+    )
+    checkTrue(.note$getNum() == 1)
+}
+
+test_checkForInstall <- function()
+{
+    if (is.null(parsedCode))
+        parsedCode <- BiocCheck:::parseFiles(system.file("testpackages",
+            "testpkg0", package="BiocCheck"))
+    res <- BiocCheck:::findSymbolInParsedCode(parsedCode, "testpkg0", "install",
+        "SYMBOL_FUNCTION_CALL")
+    checkTrue(res == 2)
+}
+
+test_checkVigBiocInst <- function()
+{
+    pkgdir <- system.file("testpackages", "testpkg0", package = "BiocCheck")
+    BiocCheck:::checkVigBiocInst(pkgdir)
+    checkTrue(.warning$getNum() == 1)
+}
+
+test_checkClassNEEQLookup <- function()
 {
     dir.create(dir <- tempfile())
-    dir.create(Rdir <- sprintf("%s%s%s", dir, .Platform$file.sep, "R"))
-    fl <- tempfile(tmpdir=Rdir)
+    dir.create(Rdir <- file.path(dir, "R"))
+    fl <- tempfile(tmpdir=Rdir, fileext = ".R")
     cat(
         paste(
-            ## good
-            "class(a)=='foo'", "class(a)!='foo'", "class(a) ==",
-            "if(class(a) ==", "class ( a ) ==",
             ## bad
-            "aclass(a) ==", "classy(a) ==",
+            "class(a)=='foo'", "class(a)!='foo'",
+            "if (is(a) == 'character')", "is( a ) != 'numeric'",
+            ## ok
+            "is(a, 'List')", "is.numeric(a)",
             sep="\n"),
         "\n", file = fl
     )
-    # create directory that should not be checked
-    # only R and vignettes checked
-    dir.create(Instdir <- sprintf("%s%s%s", dir, .Platform$file.sep, "inst"))
-    fl <- tempfile(tmpdir=Instdir)
-    cat(
-        paste(
-            ## good
-            "class(a)=='foo'", "class(a)!='foo'", "class(a) ==",
-            "if(class(a) ==", "class ( a ) ==",
-            ## bad
-            "aclass(a) ==", "classy(a) ==",
-            sep="\n"),
-        "\n", file = fl
-    )
-    match <- BiocCheck:::checkClassEqUsage(dir)
-    lines <- sub(".* (\\d)\\)$", "\\1", match)
-    checkIdentical(1:5, as.integer(lines))
+    match <- BiocCheck:::checkClassNEEQLookup(dir)
+    checkIdentical(4L, length(match))
 }
 
 test_checkDescriptionNamespaceConsistency <- function()
@@ -635,7 +802,7 @@ test_checkForBadDepends <- function()
     checkEquals(1, BiocCheck:::.error$getNum())
     checkEquals(1, BiocCheck:::.note$getNum())
     checkTrue(grepl("providing 1 object", BiocCheck:::.error$get()[1]))
-    checkTrue(grepl("how 4 object", BiocCheck:::.note$get()[1]))
+    checkTrue(grepl("how 5 object", BiocCheck:::.note$get()[1]))
 }
 
 test_remotesUsage <- function()
@@ -651,6 +818,15 @@ test_remotesUsage <- function()
     checkEquals(0, BiocCheck:::.error$getNum())
 }
 
+test_LazyDataUsage <- function()
+{
+    pkg <- system.file("testpackages", "testpkg0", package="BiocCheck")
+    BiocCheck:::.zeroCounters()
+    BiocCheck:::checkLazyDataUsage(pkg)
+    checkEquals(1, BiocCheck:::.note$getNum())
+}
+
+
 test_doesFileLoadPackage <- function()
 {
     df <- getParseData(parse(system.file("testpackages", "testpkg0",
@@ -805,6 +981,47 @@ test_checkForBiocDevelSubscription <- function()
 
 }
 
+test_checkForSupportSiteRegistration <- function()
+{
+    connect <- suppressWarnings(
+        tryCatch({
+            readBin("https://support.bioconductor.org", n=1L, what="raw")
+            TRUE
+        }, error = function(...) {
+            FALSE
+        })
+    )
+
+    if (connect) {
+
+        # Email registration
+        .zeroCounters()
+        BiocCheck:::checkSupportReg("lori.shepherd@roswellpark.org")
+        checkTrue(stillZero())
+        BiocCheck:::checkSupportReg("foo@bar.com")
+        checkEquals(.error$getNum(), 1)
+        .zeroCounters()
+        ## api is case insensitivy
+        BiocCheck:::checkSupportReg("lori.shePhErd@roswellpark.org")
+        checkTrue(stillZero())
+
+
+        # tags
+        BiocCheck:::checkWatchedTag("lori.shepherd@roswellpark.org", "biocfilecache")
+        checkTrue(stillZero())
+        BiocCheck:::checkWatchedTag("lori.shepherd@roswellpark.org", "unwatchedpackage")
+        checkEquals(.error$getNum(), 1)
+        .zeroCounters()
+        ## email is case insensitive
+        BiocCheck:::checkWatchedTag("lori.shePherd@rosWellpark.org", "biocfilecache")
+        checkTrue(stillZero())
+        ## check tag is case insenstive
+        BiocCheck:::checkWatchedTag("lori.shepherd@rosWellpark.org", "bioCfiLecache")
+        checkTrue(stillZero())
+
+    }
+}
+
 test_checkForVersionNumberMismatch <- function()
 {
     pkgpath <- create_test_package('badpkg', list(Version="0.0.1"))
@@ -850,15 +1067,16 @@ test_checkForDirectSlotAccess <- function()
 
 test_checkRVersionDependency <- function()
 {
+    .zeroCounters()
     desc <- file.path(tempdir(), "DESCRIPTION")
     cat("Depends: R (>= 1.0.0)", file=desc)
     BiocCheck:::checkRVersionDependency(dirname(desc))
-    checkEquals(.warning$getNum(), 1)
+    checkEquals(.note$getNum(), 1)
     .zeroCounters()
 
     cat("Depends: R", file=desc)
     BiocCheck:::checkRVersionDependency(dirname(desc))
-    checkEquals(.warning$getNum(), 0)
+    checkEquals(.note$getNum(), 0)
     .zeroCounters()
 
     cat("Imports: foobar)", file=desc)
@@ -868,7 +1086,7 @@ test_checkRVersionDependency <- function()
 
     cat("Depends: R (>= 10000.0.0)", file=desc) # this test might fail some day!
     BiocCheck:::checkRVersionDependency(dirname(desc))
-    checkEquals(.warning$getNum(), 0)
+    checkEquals(.note$getNum(), 0)
     .zeroCounters()
 
     unlink(desc)
@@ -890,24 +1108,35 @@ test_doesManPageHaveRunnableExample <- function()
 test_packageAlreadyExists <- function()
 {
     .zeroCounters()
-    BiocCheck:::checkIsPackageAlreadyInRepo("GenomicRanges", "CRAN")
+    BiocCheck:::checkIsPackageNameAlreadyInUse("GenomicRanges", "CRAN")
     checkEquals(.error$getNum(),0)
-    BiocCheck:::checkIsPackageAlreadyInRepo("devtools", "CRAN")
+    BiocCheck:::checkIsPackageNameAlreadyInUse("devtools", "CRAN")
     checkEquals(.error$getNum(),1)
-    BiocCheck:::checkIsPackageAlreadyInRepo("GenomicRanges", "BioCsoft")
+    BiocCheck:::checkIsPackageNameAlreadyInUse("GenomicRanges", "BioCsoft")
     checkEquals(.error$getNum(),2)
-    BiocCheck:::checkIsPackageAlreadyInRepo("GO.db", "BioCann")
+    BiocCheck:::checkIsPackageNameAlreadyInUse("GO.db", "BioCann")
     checkEquals(.error$getNum(),3)
-    BiocCheck:::checkIsPackageAlreadyInRepo("TENxBrainData", "BioCexp")
+    BiocCheck:::checkIsPackageNameAlreadyInUse("TENxBrainData", "BioCexp")
     checkEquals(.error$getNum(),4)
-    BiocCheck:::checkIsPackageAlreadyInRepo("annotation", "BioCworkflows")
+    BiocCheck:::checkIsPackageNameAlreadyInUse("annotation", "BioCworkflows")
     checkEquals(.error$getNum(),5)
-    BiocCheck:::checkIsPackageAlreadyInRepo("GenomicRanges", "BioCexp")
+    BiocCheck:::checkIsPackageNameAlreadyInUse("GenomicRanges", "BioCexp")
     checkEquals(.error$getNum(),5)
-    BiocCheck:::checkIsPackageAlreadyInRepo("GenomicRanges", "BioCann")
+    BiocCheck:::checkIsPackageNameAlreadyInUse("GenomicRanges", "BioCann")
     checkEquals(.error$getNum(),5)
-    BiocCheck:::checkIsPackageAlreadyInRepo("GenomicRanges", "BioCworkflows")
+    BiocCheck:::checkIsPackageNameAlreadyInUse("GenomicRanges", "BioCworkflows")
     checkEquals(.error$getNum(),5)
+    BiocCheck:::checkIsPackageNameAlreadyInUse("ImNotFound", "BioCexp")
+    checkEquals(.error$getNum(),5)
+    BiocCheck:::checkIsPackageNameAlreadyInUse("ImNotFound", "BioCann")
+    checkEquals(.error$getNum(),5)
+    BiocCheck:::checkIsPackageNameAlreadyInUse("ImNotFound", "BioCworkflows")
+    checkEquals(.error$getNum(),5)
+    BiocCheck:::checkIsPackageNameAlreadyInUse("ImNotFound", "CRAN")
+    checkEquals(.error$getNum(),5)
+    BiocCheck:::checkIsPackageNameAlreadyInUse("ImNotFound", "BioCsoft")
+    checkEquals(.error$getNum(),5)
+    .zeroCounters()
 }
 
 test_checkUsageOfDont <- function()
